@@ -1,10 +1,11 @@
 # Oxford University calendar conversion.
 # Simon Cozens (c) 1999-2002
 # Eugene van der Pijll (c) 2004
-# Dominic Hargreaves / University of Oxford (c) 2007-2015
+# University of Oxford (c) 2007-2015
+# Dominic Hargreaves (c) 2016
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.10";
+$Oxford::Calendar::VERSION = "2.11";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
@@ -46,7 +47,7 @@ University.
 The Terms of the University are defined by the
 B<Regulations on the number and lengths of terms>, available online from
 
-L<http://www.admin.ox.ac.uk/examregs/03-00_REGULATIONS_ON_THE_NUMBER_AND_LENGTH_OF_TERMS.shtml>
+L<https://www.admin.ox.ac.uk/examregs/2015-16/rotnalengofterm/>
 
 This document describes the start and end dates of Oxford Terms.
 
@@ -581,8 +582,8 @@ Simon Cozens is the original author of this module.
 Eugene van der Pijll, C<pijll@cpan.org> took over maintenance from
 Simon for a time.
 
-Dominic Hargreaves currently maintains this module for
-IT Services, University of Oxford.
+Dominic Hargreaves maintains this module (between 2008 and 2015 for
+IT Services, University of Oxford).
 
 =cut
 
@@ -625,7 +626,6 @@ Calendar:
     start: 15/01/2017
   Hilary 2018:
     start: 14/01/2018
-    provisional: 1
   Hilary 2019:
     start: 13/01/2019
     provisional: 1
@@ -635,6 +635,9 @@ Calendar:
   Hilary 2021:
     start: 17/01/2021
     provisional: 1
+  Hilary 2022:
+    start: 16/01/2022
+    provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
   Michaelmas 2002:
@@ -669,7 +672,6 @@ Calendar:
     start: 09/10/2016
   Michaelmas 2017:
     start: 08/10/2017
-    provisional: 1
   Michaelmas 2018:
     start: 07/10/2018
     provisional: 1
@@ -679,6 +681,9 @@ Calendar:
   Michaelmas 2020:
     start: 11/10/2020
     provisional: 1
+  Michaelmas 2021:
+    start: 10/10/2021
+    provisional: 1
   Trinity 2001:
     start: 22/04/2001
   Trinity 2002:
@@ -715,7 +720,6 @@ Calendar:
     start: 23/04/2017
   Trinity 2018:
     start: 22/04/2018
-    provisional: 1
   Trinity 2019:
     start: 28/04/2019
     provisional: 1
@@ -725,3 +729,6 @@ Calendar:
   Trinity 2021:
     start: 25/04/2021
     provisional: 1
+  Trinity 2022:
+    start: 24/04/2022
+    provisional: 1
